@@ -123,7 +123,7 @@ with requests.Session() as session:
 
 
     def create_log(payload):
-        print('create_log => ' + user_api_key)
+        print('create_log => ' + str(user_api_key))
         response = session.post(f'{HttpClientConfig.alertNowURL}/integration/appinsight/v1/{user_api_key}',
                                 data=jsonpickle.encode(payload))
         return response
